@@ -6,8 +6,10 @@
 #' character
 #' @examples
 #' \dontrun{head(get_texpackages())}
-
-get_texpackages=function(){
+#' @concept utils
+#' @rdname get_texpackages
+#' @aliases getTexPackages
+get_texpackages <- function(){
   
   if (Sys.info()[1] == "Windows"){
     
@@ -26,4 +28,4 @@ get_texpackages=function(){
     gsub('^i |:(.*?)$','',x)
     
   }
-}
\ No newline at end of file
+}
